@@ -15,7 +15,7 @@ from django.db.models.functions import TruncDay, Round
 from xj_user.services.user_relate_service import UserRelateToUserService
 from xj_user.services.user_service import UserService
 from ..models import Enroll, EnrollRecord, EnrollSubitemRecord
-from ..utils.custom_tool import format_params_handle
+from ..utils.custom_tool import format_params_handle, force_transform_type
 from ..utils.join_list import JoinList
 
 
@@ -25,7 +25,7 @@ class EnrollStatisticsServices(object):
     @staticmethod
     def every_one_total(params=None, need_Pagination=True):
         """
-        每个人汇总统计报名表（后台展示），可以根据事件和状态码筛选。
+        每个客户汇总统计报名表（后台展示），可以根据事件和状态码筛选。
         :param params:
         :return: [{
         "user_id":用户ID,
@@ -49,7 +49,7 @@ class EnrollStatisticsServices(object):
             param_dict=params,
             filter_filed_list=[
                 # ID 编码 code 等等筛选
-                "enroll_id", "thread_id", "category_id", "user_id", "enroll_rule_group_id", "trading_relate", "region_code",
+                "enroll_id", "thread_id", "category_id", "user_id", "user_id_list", "enroll_rule_group_id", "trading_relate", "region_code",
                 "occupy_room", "enroll_status_code", "user_relate_type_id",
                 # 布尔条件筛选
                 "need_vouch", "need_deposit", "need_imprest", "enable_pool", "hide_price", "hide_user", "has_repeat",
@@ -68,7 +68,7 @@ class EnrollStatisticsServices(object):
             ],
             remove_filed_list=None,
             alias_dict={
-                "enroll_id": "id",
+                "enroll_id": "id", "user_id_list": "user_id__in",
                 # 时间区间还原成orm表达式
                 "open_time_start": "open_time__gte", "close_time_start": "close_time__gte", "launch_time_start": "launch_time__gte", "finish_time_start": "finish_time__gte",
                 "spend_time_start": "spend_time__gte", "create_time_start": "create_time__gte", "update_time_start": "update_time__gte", "open_time_end": "open_time__lte",
@@ -333,3 +333,48 @@ class EnrollStatisticsServices(object):
         total__undertake_num = EnrollRecord.objects.filter(user_id=user_id).exclude(enroll_status_code=124).count()
 
         return {"today_order_num": today_order_num, "today__undertake_num": today__undertake_num, "total_order_num": total_order_num, "total__undertake_num": total__undertake_num}, None
+
+
+class RecordStatisticsService(object):
+    """报名记录统计"""
+
+    @staticmethod
+    def every_one_statistics(params=None, need_Pagination=True, exclude_code=124, **kwargs):
+        """
+        :param params:
+        :param need_Pagination:
+        :param kwargs:
+        :return:
+        """
+        params, err = force_transform_type(variable=params, var_type="only_dict", default={})
+        kwargs, err = force_transform_type(variable=kwargs, var_type="only_dict", default={})
+        params.update(kwargs)
+        page, err = force_transform_type(variable=params.get("page"), var_type="int", default=1)
+        size, err = force_transform_type(variable=params.get("size"), var_type="int", default=10)
+        params = format_params_handle(
+            param_dict=params,
+            filter_filed_list=["user_id", "user_id_list"],
+            split_list=["user_id_list"],
+            alias_dict={"user_id_list": "user_id__in"}
+        )
+        record_obj = EnrollRecord.objects.filter(**params)
+        if exclude_code:
+            record_obj = record_obj.exclude(enroll_status_code=exclude_code)
+        record_obj = record_obj.values("user_id").annotate(
+            total_record=Count("id"),
+            avg_score=Avg("score"),
+        ).values("user_id", "total_record", "avg_score")
+        total = record_obj.count()
+
+        if not need_Pagination and total <= 500:
+            result_list = list(record_obj)
+            for i in result_list:
+                i["avg_score"] = round(i["avg_score"], 2)
+            return result_list, None
+
+        paginator = Paginator(record_obj, size)
+        try:
+            record_obj = paginator.page(page)
+        except EmptyPage:
+            return {'total': total, "page": page, "size": size, 'list': []}, None
+        return {'total': total, "page": page, "size": size, 'list': list(record_obj.object_list)}, None
